==> trend_etl-1.4.14.tar.gz: trend_etl-1.4.14/setup.py <==
from setuptools import setup, find_packages  # type: ignore

setup(
    name="trend_etl",
    version="1.4.14",
    author="Charles Conroy",
    author_email="cconroy@trend.community",
    url="https://github.com/trend-community/data-engineering",
    description="Library for helpers used for ETL jobs.",
    python_requires=">=3.8",
    packages=find_packages(),
    entry_points={
        "read_kafka_subreddits": "read_kafka_subreddits=trend_etl.tasks.read_kafka_subreddits:main",
        "read_kafka_submissions": "read_kafka_submissions=trend_etl.tasks.read_kafka_submissions:main",
        "read_kafka_replies": "read_kafka_replies=trend_etl.tasks.read_kafka_replies:main",
        "read_kafka_guilds": "read_kafka_guilds=trend_etl.tasks.read_kafka_guilds:main",
        "read_kafka_channels": "read_kafka_channels=trend_etl.tasks.read_kafka_channels:main",
        "read_kafka_messages": "read_kafka_messages=trend_etl.tasks.read_kafka_messages:main",
        "read_kafka_reactions": "read_kafka_reactions=trend_etl.tasks.read_kafka_reactions:main",
        "read_kafka_members": "read_kafka_members=trend_etl.tasks.read_kafka_members:main",
        "uuid_assignment": "uuid_assignment=trend_etl.tasks.uuid_assignment:main",
        "load_community_groups": "load_community_groups=trend_etl.tasks.load_community_groups:main",
        "load_groups": "load_groups=trend_etl.tasks.load_groups:main",
        "load_groups_append": "load_groups_append=trend_etl.tasks.load_groups_append:main",
        "load_subreddits": "load_subreddits=trend_etl.tasks.load_subreddits:main",
        "load_subreddits_append": "load_subreddits_append=trend_etl.tasks.load_subreddits_append:main",
        "load_posts": "load_posts=trend_etl.tasks.load_posts:main",
        "load_posts_append": "load_posts_append=trend_etl.tasks.load_posts_append:main",
        "load_submissions": "load_submissions=trend_etl.tasks.load_submissions:main",
        "load_submissions_append": "load_submissions_append=trend_etl.tasks.load_submissions_append:main",
        "load_comments": "load_comments=trend_etl.tasks.load_comments:main",
        "load_comments_append": "load_comments_append=trend_etl.tasks.load_comments_append:main",
        "load_replies": "load_replies=trend_etl.tasks.load_replies:main",
        "load_replies_append": "load_replies_append=trend_etl.tasks.load_replies_append:main",
        "load_guilds": "load_guilds=trend_etl.tasks.load_guilds:main",
        "load_guilds_append": "load_guilds_append=trend_etl.tasks.load_guilds_append:main",
        "load_channels": "load_channels=trend_etl.tasks.load_channels:main",
        "load_channels_append": "load_channels_append=trend_etl.tasks.load_channels_append:main",
        "load_messages": "load_messages=trend_etl.tasks.load_messages:main",
        "load_messages_append": "load_messages_append=trend_etl.tasks.load_messages_append:main",
        "load_reactions": "load_reactions=trend_etl.tasks.load_reactions:main",
        "load_reactions_append": "load_reactions_append=trend_etl.tasks.load_reactions_append:main",
        "load_members": "load_members=trend_etl.tasks.load_members:main",
        "load_members_append": "load_members_append=trend_etl.tasks.load_members_append:main",
        "load_docs": "load_docs=trend_etl.tasks.load_docs:main",
        "load_docs_append": "load_docs_append=trend_etl.tasks.load_docs_append:main",
        "report_statements": "report_statements=trend_etl.tasks.report_statements:main",
        "report_discord_stats": "report_discord_stats=trend_etl.tasks.report_discord_stats:main",
        "classify_new_subreddits": "classify_new_subreddits=trend_etl.tasks.classify_new_subreddits:main",
        "dump_discord_metadata": "dump_discord_metadata=trend_etl.tasks.dump_discord_metadata:main",
        "validate_nlp_annotations": "validate_nlp_annotations=trend_etl.tasks.validate_nlp_annotations:main",
    },
    install_requires=[
        "pyspark>=3.4,<3.5",
        "delta-spark",
        "boto3",
        "boto3-stubs[essential]",
        "numpy>=1.0.0,<2.0.0",
        "pandas>=2.0.0,<3.0.0",
        "slack_sdk",
    ],
    extras_require={
        "develop": [
            "setuptools",
            "mypy",
            "build",
            "pandas-stubs",
            "pyarrow",
            # "databricks-connect",
        ],
        "ci": [
            "setuptools",
            "mypy",
            "build",
            "devpi-client",
            "pandas-stubs",
            "pyarrow",
        ],
        "analysis": [
            "spacy[cuda11x,transformers,lookups]>=3.4,<3.5",
        ],
        "classify": [
            "datasets>=2.14,<2.15",
            "transformers>=4.32,<4.33",
            "tensorflow>=2.13,<2.14",
        ],
    },
)

==> trend_etl-2.0.0a4.tar.gz: trend_etl-2.0.0a4/setup.py <==
from setuptools import setup, find_packages  # type: ignore

setup(
    name="trend_etl",
    version="2.0.0a4",
    author="Charles Conroy",
    author_email="cconroy@trend.community",
    url="https://github.com/trend-community/data-engineering",
    description="Library for helpers used for ETL jobs.",
    python_requires=">=3.8,<3.11",
    packages=find_packages(),
    entry_points={
        "read_kafka_subreddits": "read_kafka_subreddits=trend_etl.tasks.read_kafka_subreddits:main",
        "read_kafka_submissions": "read_kafka_submissions=trend_etl.tasks.read_kafka_submissions:main",
        "read_kafka_replies": "read_kafka_replies=trend_etl.tasks.read_kafka_replies:main",
        "read_kafka_guilds": "read_kafka_guilds=trend_etl.tasks.read_kafka_guilds:main",
        "read_kafka_channels": "read_kafka_channels=trend_etl.tasks.read_kafka_channels:main",
        "read_kafka_messages": "read_kafka_messages=trend_etl.tasks.read_kafka_messages:main",
        "read_kafka_reactions": "read_kafka_reactions=trend_etl.tasks.read_kafka_reactions:main",
        "read_kafka_members": "read_kafka_members=trend_etl.tasks.read_kafka_members:main",
        "uuid_assignment": "uuid_assignment=trend_etl.tasks.uuid_assignment:main",
        "load_community_groups": "load_community_groups=trend_etl.tasks.load_community_groups:main",
        "load_groups": "load_groups=trend_etl.tasks.load_groups:main",
        "load_groups_ao": "load_groups_ao=trend_etl.tasks.load_groups_ao:main",
        "load_subreddits": "load_subreddits=trend_etl.tasks.load_subreddits:main",
        "load_subreddits_ao": "load_subreddits_ao=trend_etl.tasks.load_subreddits_ao:main",
        "load_posts": "load_posts=trend_etl.tasks.load_posts:main",
        "load_posts_ao": "load_posts_ao=trend_etl.tasks.load_posts_ao:main",
        "load_submissions": "load_submissions=trend_etl.tasks.load_submissions:main",
        "load_submissions_ao": "load_submissions_ao=trend_etl.tasks.load_submissions_ao:main",
        "load_comments": "load_comments=trend_etl.tasks.load_comments:main",
        "load_comments_ao": "load_comments_ao=trend_etl.tasks.load_comments_ao:main",
        "load_replies": "load_replies=trend_etl.tasks.load_replies:main",
        "load_replies_ao": "load_replies_ao=trend_etl.tasks.load_replies_ao:main",
        "load_guilds": "load_guilds=trend_etl.tasks.load_guilds:main",
        "load_guilds_ao": "load_guilds_ao=trend_etl.tasks.load_guilds_ao:main",
        "load_channels": "load_channels=trend_etl.tasks.load_channels:main",
        "load_channels_ao": "load_channels_ao=trend_etl.tasks.load_channels_ao:main",
        "load_messages": "load_messages=trend_etl.tasks.load_messages:main",
        "load_messages_ao": "load_messages_ao=trend_etl.tasks.load_messages_ao:main",
        "load_reactions": "load_reactions=trend_etl.tasks.load_reactions:main",
        "load_reactions_ao": "load_reactions_ao=trend_etl.tasks.load_reactions_ao:main",
        "load_members": "load_members=trend_etl.tasks.load_members:main",
        "load_members_ao": "load_members_ao=trend_etl.tasks.load_members_ao:main",
        "load_docs": "load_docs=trend_etl.tasks.load_docs:main",
        "load_docs_append": "load_docs_append=trend_etl.tasks.load_docs_append:main",
        "report_statements": "report_statements=trend_etl.tasks.report_statements:main",
        "report_statements_ao": "report_statements_ao=trend_etl.tasks.report_statements_ao:main",
        "report_discord_stats": "report_discord_stats=trend_etl.tasks.report_discord_stats:main",
        "classify_new_subreddits": "classify_new_subreddits=trend_etl.tasks.classify_new_subreddits:main",
        "dump_discord_metadata": "dump_discord_metadata=trend_etl.tasks.dump_discord_metadata:main",
        "validate_nlp_annotations": "validate_nlp_annotations=trend_etl.tasks.validate_nlp_annotations:main",
        "canonicalize_discord": "canonicalize_discord=trend_etl.tasks.canonicalize_discord:main",
        "canonicalize_facebook": "canonicalize_facebook=trend_etl.tasks.canonicalize_facebook:main",
        "canonicalize_reddit": "canonicalize_reddit=trend_etl.tasks.canonicalize_reddit:main",
        "materialize_csrl_results": "materialize_csrl_results=trend_etl.tasks.materialize_csrl_results:main",
        "materialize_nlp_results": "materialize_nlp_results=trend_etl.tasks.materialize_nlp_results:main",
    },
    install_requires=[
        "slack_sdk",
    ],
    extras_require={
        "develop": [
            "psycopg2>=2.0.0,<3.0.0",
            "pyspark>=3.3,<3.4",
            "setuptools",
            "delta-spark",
            "mypy",
            "build",
            "numpy>=1.0.0,<2.0.0",
            "pandas>=2.0.0,<3.0.0",
            "pandas-stubs",
            "pyarrow",
            # "databricks-connect",
        ],
        "ci": [
            "psycopg2>=2.0.0,<3.0.0",
            "pyspark>=3.3,<3.4",
            "setuptools",
            "delta-spark",
            "mypy",
            "build",
            "numpy>=1.0.0,<2.0.0",
            "pandas>=2.0.0,<3.0.0",
            "devpi-client",
            "pandas-stubs",
            "pyarrow",
            "wheel",
            "twine",
        ],
        "analysis": [
            "spacy[cuda11x,transformers,lookups]>=3.4,<3.5",
        ],
        "classify": [
            "datasets>=2.14,<2.15",
            "transformers>=4.32,<4.33",
            "tensorflow>=2.13,<2.14",
        ],
    },
)
